#
# spec file for package logwarn
#
# Copyright (c) 2022 SUSE LLC
# Copyright (c) 2010-2011 Archie L. Cobbs. All rights reserved.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           logwarn
Version:        1.0.17
Release:        1.5
Summary:        Utility for finding interesting messages in log files
License:        Apache-2.0
Group:          System/Monitoring
URL:            https://github.com/archiecobbs/%{name}/
Source:         %{name}/%{name}-%{version}.tar.gz
BuildRequires:  automake
BuildRequires:  gcc
BuildRequires:  make
BuildRequires:  nagios-rpm-macros

%description
%{name} searches for interesting messages in log files, where ``interest-
ing'' is defined by an user-supplied list of positive and negative (pre-
ceeded with a ``!'') extended regular expressions provided on the command
line.

Each log message is compared against each pattern in the order given.  If
the log message matches a positive pattern before matching a negative
!pattern then it's printed to standard output.

%{name} keeps track of its position between invocations, so each matching
line is only ever output once.  It also finds messages in log files that
have been rotated (and possibly compressed) since the previous invoca-
tion.

%{name} also includes support for log messages that span multiple lines.

%prep
%autosetup -p1

%build
./autogen.sh
%configure
%make_build

%check
%make_build tests

%install
%make_install
install -d %{buildroot}%{_var}/lib/%{name}
install -d %{buildroot}%{_docdir}/%{name}
install COPYING %{buildroot}%{_docdir}/%{name}/
rm -rf %{buildroot}%{_docdir}/%{name}/INSTALL

%files
%attr(0755,root,root) %{_bindir}/%{name}
%attr(0644,root,root) %{_mandir}/man1/%{name}.1.gz
%defattr(0644,root,root,0755)
%{_var}/lib/%{name}
%doc %{_docdir}/%{name}

%package nagios-plugin
Summary:        Nagios plugin based on the logwarn(1) utility
Group:          System/Monitoring
Requires:       bash
Requires:       logwarn >= %{version}
BuildArch:      noarch

%description nagios-plugin
%{name} searches for interesting messages in log files, where ``interest-
ing'' is defined by an user-supplied list of positive and negative (pre-
ceeded with a ``!'') extended regular expressions provided on the command
line.

This package contains the Nagios plugin that is based on %{name}.

%files nagios-plugin
%defattr(0755,root,root,0755)
# avoid build dependecy of nagios - own the dirs
%dir %{nagios_libdir}
%dir %{nagios_plugindir}
%{nagios_plugindir}/check_logwarn

%changelog
* Sat May 28 2022 Archie Cobbs <archie.cobbs@gmail.com>
- Upgrade to release 1.0.17
  + Use fstat(2) instead of stat(2) to avoid tiny race condition
  + Fix bug when parsing consecutive "-T" flags
* Sun Nov 21 2021 Archie Cobbs <archie.cobbs@gmail.com>
- Fix bug with spec file - source shouldn't be using URL
* Sun Nov 21 2021 Archie Cobbs <archie.cobbs@gmail.com>
- Upgrade to release 1.0.16
  + Store repeated timestamps more efficiently in state file
  + Fixed infinite loop in Nagios plugin '-C' flag (issue #29)
  + Fixed crash when "-T X/Y" flag was the last command line argument
* Sun Nov 21 2021 Archie Cobbs <archie.cobbs@gmail.com>
- Replace source tarball with _service file pulling from github
* Wed Oct 27 2021 Archie Cobbs <archie.cobbs@gmail.com>
- Run spec-cleaner on spec file
* Thu Mar 19 2020 Archie Cobbs <archie.cobbs@gmail.com>
- Upgrade to release 1.0.15
  + Added "-C" flag to Nagios plugin (issue #28).
  + Allow "-T X/Y" flag as the final command line argument
* Fri Jun 24 2016 archie.cobbs@gmail.com
- Upgrade to release 1.0.14
  + Fix bug where `-T' suppressed everything when used with `-p'
  + Fix bug where `-T' would also count negative patterns
  + Fix segfault parsing `-T' in certain cases
* Mon Jun 20 2016 archie.cobbs@gmail.com
- Add 7eac274.patch
  + Fixes bug where `-T' would also count negative patterns
- Add 3a874b0.patch
  + Fixes bug where `-T' suppressed everything when used with `-p'
* Sun Jun 19 2016 archie.cobbs@gmail.com
- Upgrade to release 1.0.13
  + Added `-T' flag for frequency filtering
* Fri May 27 2016 archie.cobbs@gmail.com
- Update project homepage URL
- Update source file URL
* Wed May 25 2016 archie.cobbs@gmail.com
- Upgrade to release 1.0.12
  + Added note to man page that the default behavior is to match
  + Fix substitution for @BASH_SHELL@ in check_logwarn script
  - Remove temporary fix check-logwarn-bash.patch
  + Moved project hosing from Google code to GitHub
  + Added `-R' flag (issue #24)
* Mon Nov 17 2014 archie@dellroad.org
- Pass BASH=/bin/bash to ./configure (variant of SR261868)
* Mon Nov 17 2014 archie@dellroad.org
- Apply check-logwarn-bash.patch fixing ${BASH} def'n in check_logwarn
* Sun Jan 12 2014 archie@dellroad.org
- Upgrade to version 1.0.11
  + Added `-l' flag (contributed by Tobias Galitzien)
  + Added `-c' flag for case-insensitive matching (issue #19)
  + Added `-N' flag to limit messages processed (issue #17)
* Wed Jan 23 2013 archie@dellroad.org
- Install COPYING into docs
- Remove INSTALL from docs
- rpmlint: fix RPM group for plugin
- rpmlint: give plugin a longer %%description
* Thu Nov 29 2012 archie@dellroad.org
- rpmlint: change spec file Group: to "System/Monitoring"
* Thu Nov 29 2012 archie@dellroad.org
- Apply package fixes
  + Spec file fixes:
  * Use correct License: name
  * Remove cleanup of %%{buildroot} from %%install section
  * Make use of nagios-rpm-macros for RPM macros
  + Include version update details in changelog
* Sun Nov 25 2012 archie@dellroad.org
- Upgrade to version 1.0.10
  + Added `-M' and `-L' command line flags
  + Added `-F' flag to Nagios plugin
* Fri Nov  9 2012 archie@dellroad.org
- Upgrade to version 1.0.9
  + Add support for rotated logs that are xz(1) compressed
  + Plugin: exit UNKNOWN instead of CRITICAL if can't create temp file
  + Plugin: add support for '-h' command line flag
  + Plugin: fix unportable sed(1) usage
  + Plugin: omit alert level from status message
* Sat Apr  7 2012 archie@dellroad.org
- Upgrade to version 1.0.8
  + Properly handle truncated files (issue #7)
  + Portability fixes for Solaris
* Fri Nov 11 2011 archie@dellroad.org
- Upgrade to version 1.0.7
  + Add large file support (issue #3)
* Tue Oct  4 2011 archie@dellroad.org
- Upgrade to version 1.0.6
  + Fix misuse of '|' character in Nagios plugin output
* Fri Sep 16 2011 archie@dellroad.org
- Upgrade to version 1.0.5
  + Added the ability to scan standard input
  + Added `-z' flag to always read from the beginning
* Fri Aug 19 2011 archie@dellroad.org
- Upgrade to version 1.0.4
  + Fixed a bug when file is less than three bytes long (issue #2)
  + Added some examples to the man page
* Mon Jan 31 2011 archie@dellroad.org
- Upgrade to version 1.0.3
  + Don't process the last line of a file if it doesn't have a newline
  + Tightend up error checking around file operations
  + Improved error message output from Nagios plugin
* Thu Dec 30 2010 archie@dellroad.org
- Update to version 1.0.2
  + Removed the automatic implication of `-n' by `-i'
  + Added `-a' flag to control auto-initialize behavior
  + Added `-p' flag to change default match to no match
  + Added `-f' flag to specify state file directly
  + Added some more man page clarifications
* Wed Dec 29 2010 archie@dellroad.org
- Make Nagios plugin architecture indepdendent.
* Wed Dec 29 2010 archie@dellroad.org
- Include /var/lib/logwarn in the RPM.
* Wed Dec 29 2010 archie@dellroad.org
- Add /usr/lib/nagios{,/plugins} to the RPM to make OBS happy.
* Wed Dec 29 2010 archie@dellroad.org
- Upgrade to version 1.0.1
  + Added some man page fixes and clarifications
  + Added a Nagios plugin
* Wed Dec 29 2010 archie@dellroad.org
- Initial checkin
